#!/usr/bin/python
# -*- encoding: utf-8 -*-

import smbus
import time
import sys


bus = smbus.SMBus(1)    # novejsi verze Raspberry Pi (512MB)
#bus = smbus.SMBus(0)    # starsi verze Raspberry Pi (256MB)

addr = 0x50   # I2C adresa citace (kdyz je noha A0 v logicke "0", je adresa 0x50)

# status registr obvodu pcf8583 nastavit na "EVENT COUNTER" bez alarmu (ALARM=disable)
bus.write_byte_data(addr,0x00,0b00100000) 

  

# nulovani registru s nacitanymi impulzy v obvodu PCF8583
def reset():
    bus.write_byte_data(addr,0x01,0x00) # vynulovat LSB
    bus.write_byte_data(addr,0x02,0x00) # vynulovat prostredni bajt
    bus.write_byte_data(addr,0x03,0x00) # vynulovat MSB
    
    
# zjisteni poctu impulzu v registrech obvodu
def zjisti_pocet():
  counter =  bus.read_i2c_block_data(addr,0x00)
  rad1 = (counter[1] & 0x0F)             # rad jednotek
  rad10 = (counter[1] & 0xF0) >> 4       # rad desitek
  rad100 = (counter[2] & 0x0F)           # rad stovek
  rad1000 = (counter[2] & 0xF0) >> 4     # rad tisicu
  rad10000 = (counter[3] & 0x0F)         # rad desetitisicu
  rad100000 = (counter[3] & 0xF0) >> 4   # rad stotisicu

  count = (rad100000 * 100000) + (rad10000 * 10000) + (rad1000 * 1000) + (rad100 * 100) + (rad10 * 10) + rad1

  return (count)
  
# nastaveni 'budiku' (pri kolika impulzech dojde k preklopeni vystupu)
def interrupt(alarm):

  reset()    # vynulovani pocitadla

  bus.write_byte_data(addr , 0x00 , 0b00100100)   # rezim "event-counter" + "alarm_enable"
  bus.write_byte_data(addr , 0x08 , 0b10010000)   # vystupni noha je aktivni + alarm od pocitadla

  # prepocet z hodnoty alarmu na 3 bajty v registrech
  rad100000 = int(alarm / 100000)              # rozlozeni cisla na jednotlive rady
  zbytek = alarm - (rad100000 * 100000)
  rad10000 = int(zbytek / 10000)
  zbytek = zbytek - (rad10000 * 10000)
  rad1000 = int(zbytek / 1000)
  zbytek = zbytek - (rad1000 * 1000)
  rad100 = int(zbytek / 100)
  zbytek = zbytek - (rad100 * 100)
  rad10 = int(zbytek / 10)
  rad1 = zbytek - (rad10 * 10)

  alarmbajt9  = (rad10     << 4) + rad1        # slozeni radu po dvojicich do jednotlivych bajtu 
  alarmbajt10 = (rad1000   << 4) + rad100
  alarmbajt11 = (rad100000 << 4) + rad10000

  bus.write_byte_data(addr,0x09,alarmbajt9)  # nastavit hodnotu do nejnizsiho z alarmovych registru
  bus.write_byte_data(addr,0x0A,alarmbajt10) # nastavit hodnotu do prostredniho z alarmovych registru
  bus.write_byte_data(addr,0x0B,alarmbajt11) # nastavit hodnotu do nejvyssiho z alarmovych registru

  print "Pocitam impulzy ..."
  print "Pri dosazeni cisla " + str(alarm) + " se vystup prepne do '0'."
  
def cyklicke_mereni(maximalni_cislo,pauza):
  count = 0
  reset()
  while count < maximalni_cislo:
    count = zjisti_pocet() 
    time.sleep(pauza)
    print "Aktualni stav pocitadla: " , count
  

  
# vyhodnoceni predavaneho parametru pri spousteni programu
try:                      # odchytavani chyby, ktera by vznikla pri chybejicim parametru
  akce = sys.argv[1]      # parametr spousteneho programu do promenne "akce"
except:                   # kdyz parametr chybi, je nahrazen prazdnym retezcem
  akce=""

akce = akce.lower()       # prevod parametru na mala pismena



if (akce == "-i"):        # zobrazeni aktualniho poctu impulzu
  print "Aktualni stav pocitadla = " , zjisti_pocet()
  
elif (akce == "-reset"):  # vynulovani pocitadla
  reset()

elif (akce == "-int"):    # nastaveni vystupu INT
  interrupt(1000)         # po kolika impulzech dojde k preklopeni vystupu

elif (akce == "-cyk"):    # opakovane zjistovani stavu pocitadla
  cyklicke_mereni(1000,0.5)    # do kolika se ma pocitat a pauza v sekundach mezi zjistovanim stavu


else:                              # pri jakemkoli jinem parametru se zobrazi napoveda
  print "Pripustne parametry:"
  print "... -i        INFO - zobrazi pocet impulzu v registrech"
  print "... -reset    Vynuluje registry"
  print "... -int      Nastavi 'budik'"
  print "... -cyk      Cyklicke mereni"
  
